@@ -1,6 +1,8 @@
-import automodinit
-from os.path import dirname, basename, isfile, join
 import glob
+from os.path import basename, dirname, isfile, join
+
+import automodinit
+
 __all__ = []
 automodinit.automodinit(__name__, __file__, globals())
 del automodinit
