@@ -59,13 +59,14 @@ class wireless:
                         net_name).upper():
                     self.overridePSK = item[const.appcfg.psk_file_psk]
                     found = True
-                    print(
-                        f'\t\t\t{lib.bc.OKGREEN} {net_name} - Network PSK Found'
-                    )
+                    if const.appcfg.enable_status:
+                        print(
+                            f'\t\t\t{lib.bc.OKGREEN} {net_name} - Network PSK Found'
+                        )
                     continue
 
         if not found:
-            if const.appcfg.debug:
+            if const.appcfg.enable_status:
                 print(
                     f'\t\t\t{lib.bc.WARNING} {self.NetworkName} - No PSK Found'
                 )
@@ -118,11 +119,12 @@ class wireless:
             for i in range(0, 15):
                 if i in self.ssids_range:  # only query/refresh the active SSIDS
                     aie_code = await lib.aironetie(net_id, i)
-                    print(
-                        f'\t\t\t{lib.bc.OKBLUE}Detecting AIE for SSID['
-                        f'{lib.bc.WARNING}{i}{lib.bc.OKBLUE}] '
-                        f'Status[{lib.bc.WARNING}{aie_code}{lib.bc.OKBLUE}]{lib.bc.ENDC}'
-                    )
+                    if const.appcfg.debug:
+                        print(
+                            f'\t\t\t{lib.bc.OKBLUE}Detecting AIE for SSID['
+                            f'{lib.bc.WARNING}{i}{lib.bc.OKBLUE}] '
+                            f'Status[{lib.bc.WARNING}{aie_code}{lib.bc.OKBLUE}]{lib.bc.ENDC}'
+                        )
                     self.aironetie.append(
                         aie_code)  # -1 for unkown, 0 for off, 1 for
             # self.aironetie
@@ -473,6 +475,7 @@ class wireless:
 
     async def Update_aironetie(self, sdk: object, org_id: str, net_id: str,
                                net_name):
+        #TODO Need to check why funciton is throwing an error
         """
 		Updates AiroNet IE Settins on the Meraki Dashboard
 		Args:
@@ -483,28 +486,29 @@ class wireless:
 		Returns:
 
 		"""
-        if const.appcfg.debug:
-            print(f'ORG ID: {org_id} - Network ID: {net_id} - {net_name}')
-        golden = lib.get_golden('wireless')
-        for i in self.ssids_range:  # and self.hasAironetIE:
-            if 'Unconfigured SSID' in self.NetworkWirelessSsid[i][
-             'name'] \
-              or 'Unconfigured SSID' in \
-              golden.NetworkWirelessSsid[i]['name']:
-                continue
-            if self.hasAironetIE and not await lib.compare(
-                    self.aironetie[i], golden.aironetie[i]):
-                if const.appcfg.write:
-                    await lib.set_aironet_ie(net_id, i, golden.aironetie[i])
-                    print(
-                        f'{lib.bc.OKBLUE}\t\tConfiguring AironetIE{lib.bc.WARNING}'
-                        f'{golden.aironetie[i]}'
-                        f'{lib.bc.OKBLUE}] on SSID[{lib.bc.WARNING}'
-                        f'{i}{lib.bc.OKBLUE}]{lib.bc.ENDC}')
-                    if self.hasAironetIE:
-                        await self.Get_aironetie(sdk, net_id, net_name)
-            else:
-                lib.print_matched(net_name, "AironetIE", "Wireless")
+        pass
+#        if const.appcfg.debug:
+#            print(f'ORG ID: {org_id} - Network ID: {net_id} - {net_name}')
+#        golden = lib.get_golden('wireless')
+        #for i in self.ssids_range:  # and self.hasAironetIE:
+        #    if 'Unconfigured SSID' in self.NetworkWirelessSsid[i][
+        #     'name'] \
+        #      or 'Unconfigured SSID' in \
+        #      golden.NetworkWirelessSsid[i]['name']:
+        #        continue
+        #    if self.hasAironetIE and not await lib.compare(
+        #            self.aironetie[i], golden.aironetie[i]):
+        #        if const.appcfg.write:
+        #            await lib.set_aironet_ie(net_id, i, golden.aironetie[i])
+        #            print(
+        #                f'{lib.bc.OKBLUE}\t\tConfiguring AironetIE{lib.bc.WARNING}'
+        #                f'{golden.aironetie[i]}'
+        #                f'{lib.bc.OKBLUE}] on SSID[{lib.bc.WARNING}'
+        #                f'{i}{lib.bc.OKBLUE}]{lib.bc.ENDC}')
+        #            if self.hasAironetIE:
+        #                await self.Get_aironetie(sdk, net_id, net_name)
+        #    else:
+        #        lib.print_matched(net_name, "AironetIE", "Wireless")
 
     async def Update_NetworkWirelessRfProfiles(self, sdk: object, org_id: str,
                                                net_id: str, net_name):
