@@ -1,8 +1,7 @@
 import os
 
 import click
-from pathlib import Path
-from dotenv import load_dotenv,dotenv_values
+
 
 @click.group()
 def cli():
@@ -12,11 +11,11 @@ def cli():
 @click.command(help='Sets the Meraki API Key as an environment variable')
 @click.option('-key','--key', required=True)
 def setkey(key):
-    os.environ['MERAKI_DASHBOARD_API_KEY'] = key
+    os.environ['meraki_dashboard_api_key'] = key
 
 @click.command(help='Display the Meraki API Key as an environment variable ')
 def showkey():
-    print(os.getenv('MERAKI_DASHBOARD_API_KEY','No key set please run autosync setkey --key <API Key> to set your key'))
+    print(os.getenv('meraki_dashboard_api_key','No key set please run autosync setkey --key <API Key> to set your key'))
 
 
 cli.add_command(setkey)
