@@ -1,16 +1,18 @@
-from autosync import Products
-
+"""
+Class May be depericated
+"""
 
+from autosync import products
 class OVERRIDES(object):
     def __init__(self):
-        self.supported_products = Products.supported
+        self.supported_products = products.supported
         self.List = self._product_functions()
     
 
     def _product_functions(self):
         List = {}
         for product in self.supported_products:
-            method = getattr(Products, product)
+            method = getattr(products, product)
             _module = dir(method)
             update = [_funct.split('_')[1] for _funct in _module if
                                   _funct.startswith('Update_')]
