@@ -65,8 +65,8 @@ class Orgsyncprocessor(threading.Thread):
             
       
         print(
-            f'OrgName: {model.meraki_nets[self.org_id].name} '
-            f'Loaded From Cache Date: {model.meraki_nets[self.org_id].lastsync}'
+            f'{lib.bc.OKBLUE} OrgName: {model.meraki_nets[self.org_id].name} '
+            f'{lib.bc.WARNING}Loaded Last Sync Time: {model.meraki_nets[self.org_id].lastsync}{lib.bc.ENDC}'
             )
 
     async def _async_run(self,has_golden):
