@@ -23,8 +23,10 @@ async def validate_network_processor(org_id: str, net_id: str,
     Returns:
 
     """
+	org_name = model.meraki_nets[org_id].name
+	net_name = model.meraki_nets[org_id].networks[net_id].name
 	print(
-			f'{lib.bc.OKGREEN}Starting Network configuration validation...{lib.bc.ENDC}'
+			f'{lib.bc.OKBLUE}{org_name} - {net_name} {lib.bc.OKGREEN}Starting configuration validation...{lib.bc.ENDC}'
 	)
 	for product in model.meraki_nets[org_id].networks[net_id].dashboard:
 		await mnetutils.clone(org_id, net_id, sdk, product)
@@ -113,9 +115,12 @@ async def proccess_network(org_id: str, net_id: str, sdk: object,
 							await mnetutils.sync(sdk, net.org_id,
 							                     net.net_id, product,
 							                     is_golden)
+					
 						except Exception as error:
 							if const.appcfg.debug:
 								print(f'Error: {error}')
+					print(
+						f'{lib.bc.OKBLUE}{net_name} Finished syncing - {lib.bc.WARNING}{product}{lib.bc.ENDC}')
 				else:
 					if const.appcfg.debug:
 						print(f"No Sync Module for {product}")
@@ -139,9 +144,10 @@ async def proccess_network(org_id: str, net_id: str, sdk: object,
 		      f'Process took: {net.syncruntime:0.5f} secounds{lib.bc.Default}')
 	
 	else:
-		t = time.perf_counter() - t1
-		print(f'Network: {net_name} '
-		      f'Skiped Syncing Process took: {t:0.5f} secounds')
+		if const.appcfg.enable_status:
+			t = time.perf_counter() - t1
+			print(f'Network: {net_name} '
+			      f'Skiped Syncing Process took: {t:0.5f} secounds')
 
 
 
